@@ -1,10 +1,14 @@
 from __future__ import unicode_literals
 
+import django
 from django.db import models
 from django.utils.translation import ugettext_lazy as _
-from django.db.models.fields import FieldDoesNotExist
 from django.core.exceptions import ImproperlyConfigured
-from django.utils.timezone import now
+if django.VERSION >= (1, 9, 0):
+    from django.db.models.functions import Now
+    now = Now()
+else:
+    from django.utils.timezone import now
 
 from model_utils.managers import QueryManager
 from model_utils.fields import AutoCreatedField, AutoLastModifiedField, \
